@@ -108,7 +108,7 @@
 // Bit number n (0<n<=32) mod 2^32
   #define bitm(n)  (2L<<((n)-1))
 // Test bit n in x, n constant, x a cl_uint:
-  #if !defined(__sparc__)
+  #if !(defined(__sparc__) || defined(__sparc64__))
     #define bit_test(x,n)  ((x) & bit(n))
   #else
     // On Sparcs long constants are slower than shifts.
